@@ -1,6 +1,7 @@
-include Showable;
+include Behavior::Showable;
+include Behavior::Buyable;
 
-class Artwork with Showable {
+class Artwork with Showable, Buyable  {
     has creation_date;
     has creator (
         is => ro,
@@ -8,7 +9,5 @@ class Artwork with Showable {
         type => ArrayRef[ Object ]
     );
     has material;
-    has owner;
     has size;
-    has value ( is => rw );
 }
