@@ -5,7 +5,7 @@ package Art::World;
 # use Art::Agent;
 #has Art::Agent::Artist @.artists;
 
-our $VERSION = '0.15_04';
+our $VERSION = '0.15_05';
 
 use Zydeco;
 
@@ -129,15 +129,34 @@ If a correct API is reached, we'll try to build a "game of art" frontend.
 
 This is a long term continuation of an art project started circa 2006.
 
+In 2005, I got a metal box and colored carton cards and called this I<Le
+Fichier>. It was basically a database of artworks ideas. I was trashing all
+ideas I could have of serious or weird potential artworks. It was inspired
+either by Roland Barthes, who was actually working with those kind of cards,
+Georges Perec, who was exploring I<potentialities>, and Édouard Levé I<Oeuvres>,
+a huge catalog of potential artworks (he later commited suicide after describing
+his own I<Suicide> in a book).
+
+2006 I initiated a FileMaker database of artworks to put the old style carton
+cards in computer form. I had no idea what I was doing at this time, being an
+art school student, at this time, programming was not massively teached at art
+school (unfortunately).
+
 In 2008 I benefited of an artist residency in an agricultural college with a
-creation grant of 10 000€. I urged to keep go on my Art World and Creative
-Processes schema projects initiated during art school. It didn't went very well
+creation grant of 10 000€. I urged to keep go on my I<Art World and Creative
+Processes schemas> projects initiated during art school. It didn't went very well
 because the then local state Plastic Art I<Inspector> didn't like what I was
 doing with her money and strongly advised to change orientation. In my idea, it
 was a perfect thing that the instutition itself would exhibit it's inherent
 processes and operations. In the end, there were an exhibition, but she didn't
 come to the opening.
 
+Anyway, I ended up interviewing many I<Agents> of the college, and went
+especially well with some natural sciences teacher. He recommended a manual were
+I found some schemas that I made some I<detournement>: I used the geology
+science as a metaphor of art world. I used geology terms and language to
+describe social interactions that are not described in the art sociology field.
+
 =begin html
 
 <p>
@@ -147,19 +166,33 @@ come to the opening.
 
 =end html
 
+The residency ended up with L<the redaction of a rather precise documentation|https://files.balik.network/art/schema_v4_presentation.pdf> (maybe my first specification).  
+
 Then I almost got hit by a fellow artist who was participating at a collective
-exhibition mostly for the money and not for the fun.
+exhibition mostly for the money and not for the fun. I guess he got a bit provocated by my situationist theory.
 
 In 2008, I finally decided to start a training to learn programming and being
 able to design a proper database and system for I<managing a virtual Art
-World>. I became a web developer, but I totally forgot the main aim. Sometimes I
-thought about it, and in 2017, I restarted my project while getting into Raku
+World>. I became a web developer, but I totally forgot the main aim.
+
+Sometimes I thought about it:
+
+=over
+
+=item 2013 Perl try
+
+I bootstraped a Perl module with 5 abstract empty classes and then let it sleep on Github
+
+=item 2017 Raku try
+
+I restarted my project while getting into Raku
 (it was still Perl6 at this time), but learning Raku was too much effort and I
 abandonned again.
 
 Ten years later I am still on it. This project is L<following me in my
 dreams|https://smonff.gitlab.io/art-school-story/>. I'll give it another try.
 
+=back
 
 =head1 AUTHOR
 
